PixelWeb

Loading...

v1.1.5

Thank you for choosing PixelWeb!

PixelWeb is Open Source, under the MIT License and provided free of charge to all. If you paid for this software, please contact Maniacal Labs via contact@maniacallabs.com to report the license violation.

For more details on PixelWeb usage, please visit the PixelWeb Wiki.

PixelWeb © 2015 - Maniacal Labs / Adam Haile

Animations
Save
Save
Cancel
Start
Stop
Queue
Save
Cancel
Quick Select
Output Setup
Start
App Config
Save
PixelWeb Status
BiblioPixel Error

OK
Save Preset
Preset Name
Description
Save
Cancel
Save Queue
Queue Name
Description
Save
Cancel
Save Quick Select
Name
Description
Save
Cancel
Delete Preset
Yes
No
Delete Queue
Yes
No
Delete Quick Select
Yes
No
Unable to Delete

OK
Configuration Required

Please configure and run the output before continuing.

OK
Server Restart Required

Please restart the server to ensure all changes take effect!

OK
Add to Queue
Description
Add
Cancel
Add to Quick Select
Name
Description
Add
Cancel